# Generated by Django 2.2.13 on 2020-10-27 18:35

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('news', '0006_auto_20201001_1556'),
    ]

    operations = [
        migrations.AddField(
            model_name='newstranslation',
            name='teaser_link_url',
            field=models.URLField(blank=True, default='', help_text='Provide a valid URL to an external website.', max_length=500, verbose_name='External link'),
        ),
    ]
