# Generated by Django 2.2.17 on 2021-01-14 08:55

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('locations', '0010_auto_20201130_1447'),
    ]

    operations = [
        migrations.RenameField(
            model_name='locations',
            old_name='country',
            new_name='country_old',
        ),
    ]
