# Generated by Django 2.2.13 on 2020-11-12 08:54

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('allink_gallery', '0002_auto_20201102_1644'),
    ]

    operations = [
        migrations.AddField(
            model_name='allinkgalleryimageplugin',
            name='width_alias',
            field=models.CharField(blank=True, max_length=50, null=True, verbose_name='Width Alias'),
        ),
        migrations.AddField(
            model_name='allinkgalleryplugin',
            name='width_alias',
            field=models.CharField(blank=True, max_length=50, null=True, verbose_name='Width Alias'),
        ),
    ]
