{% load allink_image_tags %}
<div class="teaser teaser--list">
    {% include 'allink_teaser/includes/_link-begin.html' %}
        <div class="teaser__col-container">
            <div class="teaser__col teaser__col-1">
                <div class="teaser__image">
                    {% render_image image=teaser_image width_alias='teaser-list' %}
                </div>
            </div>
            <div class="teaser__col teaser__col-2 teaser__content">
                {% include 'allink_teaser/includes/_technical-title.html' with teaser_technical_title=teaser_technical_title %}
                {% include 'allink_teaser/includes/_title.html' with teaser_title=teaser_title %}
                {% include 'allink_teaser/includes/_description.html' with teaser_description=teaser_description %}
                {% include 'allink_teaser/includes/_button-wrapper.html' %}
            </div>
        </div>
    {% include 'allink_teaser/includes/_link-end.html' %}
</div>
