# Generated by Django 2.2.16 on 2021-03-16 22:13

from django.db import migrations, models
import django.db.models.deletion
import djangocms_text_ckeditor.fields


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('cms', '0022_auto_20180620_1551'),
    ]

    operations = [
        migrations.CreateModel(
            name='AllinkListMulticolPlugin',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, related_name='allink_list_multicol_allinklistmulticolplugin', serialize=False, to='cms.CMSPlugin')),
                ('text', djangocms_text_ckeditor.fields.HTMLField(blank=True, help_text='Numbered and bulleted lists in this text will automatically be displayed in multiple columns.', null=True, verbose_name='Text')),
                ('column_mode', models.IntegerField(choices=[(0, 'Two Columns'), (1, 'Three Columns')], default=0, verbose_name='Columns')),
            ],
            options={
                'abstract': False,
            },
            bases=('cms.cmsplugin',),
        ),
    ]
