# Generated by Django 2.2.13 on 2020-11-02 16:44

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('allink_gallery', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='allinkgalleryplugin',
            name='auto_start_enabled',
            field=models.BooleanField(default=False, help_text='This option enables autoplay for this gallery.', verbose_name='Autostart'),
        ),
    ]
