# Generated by Django 2.2.16 on 2020-11-13 08:09

import cms.models.fields
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('cms', '0022_auto_20180620_1551'),
        ('people', '0005_auto_20201001_1556'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='peopleappcontentplugin',
            name='load_more_link',
        ),
        migrations.AddField(
            model_name='peopleappcontentplugin',
            name='load_more_internallink',
            field=cms.models.fields.PageField(blank=True, help_text='Link for Button Below Items if custom URL is chosen', null=True, on_delete=django.db.models.deletion.CASCADE, related_name='load_more_internallink_people', to='cms.Page', verbose_name='Custom Load More Link'),
        ),
        migrations.AddField(
            model_name='peopletranslation',
            name='teaser_link_url',
            field=models.URLField(blank=True, help_text='Provide a valid URL to an external website.', max_length=500, null=True, verbose_name='External link'),
        ),
    ]
