# Generated by Django 2.2.19 on 2021-04-22 18:52

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('allink_legacy_redirect', '0003_auto_20191016_0804'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='allinklegacylink',
            name='redirect_when_logged_out',
        ),
        migrations.AddField(
            model_name='allinklegacylink',
            name='skip_redirect_when_logged_in',
            field=models.BooleanField(default=False, help_text='If True, current site will not redirect when user is logged in. If False, the page will be redirected.', verbose_name='Skip redirect when logged in'),
        ),
    ]
