<div class="teaser teaser--tile">
    {% include 'allink_teaser/includes/_link-begin.html' %}
        {% include 'allink_teaser/includes/_image.html' with teaser_image=teaser_image %}

        <div class="teaser__content">
            {% include 'allink_teaser/includes/_technical-title.html' with teaser_technical_title=teaser_technical_title %}
            {% include 'allink_teaser/includes/_title.html' with teaser_title=teaser_title %}
            {% include 'allink_teaser/includes/_description.html' with teaser_description=teaser_description %}
            {% include 'allink_teaser/includes/_button-wrapper.html' %}
        </div>
    {% include 'allink_teaser/includes/_link-end.html' %}
</div>
