# Generated by Django 2.2.17 on 2021-01-14 09:00

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('locations', '0011_auto_20210114_0855'),
    ]

    operations = [
        migrations.AddField(
            model_name='locationstranslation',
            name='country',
            field=models.CharField(blank=True, max_length=255, null=True, verbose_name='Country'),
        ),
    ]
