# Generated by Django 2.2.16 on 2020-10-30 11:12

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('config', '0004_allinktitleextension_teaser_link_url'),
    ]

    operations = [
        migrations.RunSQL("""DELETE FROM django_migrations WHERE app='contact' AND name='0001_initial';""")
    ]
