# Generated by Django 2.2.16 on 2021-03-26 10:19

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('allink_image_svg', '0002_auto_20210325_1703'),
    ]

    operations = [
        migrations.AddField(
            model_name='allinkimagesvgplugin',
            name='is_fullwidth',
            field=models.BooleanField(default=True, help_text='Stretches the SVG to 100% width.', verbose_name='Is Fullwidth'),
        ),
    ]
