# Generated by Django 2.2.16 on 2021-03-25 17:03

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('allink_image_svg', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='allinkimagesvgplugin',
            name='is_inline',
            field=models.BooleanField(default=False, help_text='Check if the SVG will be inlined.', verbose_name='Is inline'),
        ),
    ]
