{% load allink_image_tags %}
<div class="teaser teaser--fullwidth inverted-colors">
    {% include 'allink_teaser/includes/_link-begin.html' %}
        <div class="teaser__image">
            {% render_image width_alias="teaser-fullwidth" image=teaser_image vh_enabled=True %}
        </div>
        <div class="teaser__overlay"></div>
        <div class="teaser__content">
            {% include 'allink_teaser/includes/_technical-title.html' with teaser_technical_title=teaser_technical_title %}
            {% include 'allink_teaser/includes/_title.html' with teaser_title=teaser_title %}
            {% include 'allink_teaser/includes/_description.html' with teaser_description=teaser_description %}
            {% include 'allink_teaser/includes/_button-wrapper.html' %}
        </div>
    {% include 'allink_teaser/includes/_link-end.html' %}
</div>
